@@ -2,9 +2,6 @@
 # Monitor::Simple
 # Author: Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer se below.
-#
-# ABSTRACT: Simple monitoring of applications and services
-# PODNAME: Monitor::Simple
 #-----------------------------------------------------------------
 
 package Monitor::Simple;
@@ -12,7 +9,21 @@ package Monitor::Simple;
 use warnings;
 use strict;
 
-our $VERSION = '0.2.8'; # VERSION
+#------------------------------------------
+# Versioning
+#------------------------------------------
+
+=head1 NAME
+
+Monitor::Simple - Simple monitoring of applications and services
+
+=head1 VERSION
+
+Version 0.1.0
+
+=cut
+
+use version; our $VERSION = 0.1;
 
 # values returned by plugins (compatible with Nagios'
 use constant {
@@ -58,13 +69,13 @@ my $default_npp = 10; # maximum number of child processes in parallel
 # configuration.
 #
 # Recognized arguments:
-#    { config_file => $config_file,
-#      npp         => <integer>,
-#      outputter   => instance of Monitor::Simple::Output,
-#      filter      => hashref (keys are service IDS) or
-#                     arrayref with service IDs, or
-#                     scalar with just one service ID
-#      nonotif     => boolean
+#    { config    => $config OR config_file => $config_file,
+#      npp       => <integer>,
+#      outputter => instance of Monitor::Simple::Output,
+#      filter    => hashref (keys are service IDS) or
+#                   arrayref with service IDs, or
+#                   scalar with just one service ID
+#      nonotif   => boolean
 #    }
 # -----------------------------------------------------------------
 sub check_services {
@@ -73,38 +84,41 @@ sub check_services {
     # recognized arguments
     my $config;
     my $config_file;
-    if ($args->{config_file}) {
-        $config_file = $args->{config_file};
-        $config = Monitor::Simple::Config->get_config ($config_file);
+    if ($args->{config}) {
+	$config = $args->{config};
+	$config_file = ($args->{config_file} || Monitor::Simple::Config->resolve_config_file ($config));
+    } elsif ($args->{config_file}) {
+	$config_file = $args->{config_file};
+	$config = Monitor::Simple::Config->get_config ($config_file);
     } else {
-        LOGDIE ("check_services: Missing argument 'config_file'. Cannot do anything.\n");
+	LOGDIE ("check_services: Missing argument 'config' or 'config_file'. Cannot do anything.\n");
     }
     my $npp = ($args->{npp} || $default_npp);
     if ($npp < 1) {
-        LOGWARN ("check_services: Argument 'npp' must be positive. Replaced by default value $default_npp.\n");
-        $npp = $default_npp;
+	LOGWARN ("check_services: Argument 'npp' must be positive. Replaced by default value $default_npp.\n");
+	$npp = $default_npp;
     }
     my $outputter = ($args->{outputter} || Monitor::Simple::Output->new (config   => $config));
 
-    # optional filter tells which only services to check; filter can be
+    # optional filter tells which only services to check filter can be
     # hashref or arrayref or scalar (all with service name(s) we wish
     # to check)
     my $filter = $args->{filter};
     if ($filter) {
-        if (ref ($filter) eq 'ARRAY') {
-            $filter = { map { $_ => 1 } @$filter };
-        } elsif (ref ($filter) eq 'HASH') {
-            # already done
-        } else {
-            $filter = { $filter => 1 };
-        }
+	if (ref ($filter) eq 'ARRAY') {
+	    $filter = { map { $_ => 1 } @$filter };
+	} elsif (ref ($filter) eq 'HASH') {
+	    # already done
+	} else {
+	    $filter = { $filter => 1 };
+	}
     }
     $filter = undef unless keys %$filter > 0;
 
     # before the main checking loop starts
     $outputter->header();
     my $notifier = Monitor::Simple::Notifier->new (config  => $config,
-                                                   cfgfile => $config_file);
+						   cfgfile => $config_file);
 
     # main loop
     INFO ('--- Checking started ---');
@@ -112,37 +126,37 @@ sub check_services {
     my $pm = new Parallel::ForkManager ($npp);
     foreach my $service (@{ $config->{services} }) {
 
-        # filtering of services
-        next if $filter and not exists $filter->{ $service->{id} };
+	# filtering of services
+	next if $filter and not $filter->{ $service->{id} };
 
-        # this does the fork and for the parent branch and continues the foreach loop
-        $pm->start and next;
+	# this does the fork and for the parent branch and continues the foreach loop
+	$pm->start and next;
 
-        # this is the child branch: execute an external plugin...
-        my $command = $service->{plugin}->{command};
-        unless (File::Spec->file_name_is_absolute ($command)) {
-            my $plugins_dir = $config->{general}->{'plugins-dir'};
-            if ($plugins_dir) {
-                $command = File::Spec->catfile ($plugins_dir, $command);
-            }
-        }
-        my @command = ($command,
-                       Monitor::Simple::Config->create_plugin_args ($config_file,
-                                                                    $config,
-                                                                    $service->{id}));
-        DEBUG ("Started: " . join (' ', @command));
-        my ($stdout, $stderr, $success, $exit_code) = capture_exec (@command);
+	# this is the child branch: execute an external plugin...
+	my $command = $service->{plugin}->{command};
+	unless (File::Spec->file_name_is_absolute ($command)) {
+	    my $plugins_dir = $config->{general}->{'plugins-dir'};
+	    if ($plugins_dir) {
+		$command = File::Spec->catfile ($plugins_dir, $command);
+	    }
+	}
+	my @command = ($command,
+		       Monitor::Simple::Config->create_plugin_args ($config_file,
+								  $config,
+								  $service->{id}));
+	DEBUG ("Started: " . join (' ', @command));
+	my ($stdout, $stderr, $success, $exit_code) = capture_exec (@command);
 
-        # ...and make the result report
-        print STDERR "$stderr\n" if $stderr;  # do not hide standard errors, if any
-        my ($code, $msg) = Monitor::Simple::Utils->process_exit ($command, $exit_code, $stdout);
-        $outputter->out ($service->{id}, $code, $msg);
-        unless (exists $args->{nonotif} and $args->{nonotif}) {
-            $notifier->notify ( { service => $service->{id},
-                                  code    => $code,
-                                  msg     => $msg } );
-        }
-        $pm->finish;
+	# ...and make the result report
+	print STDERR "$stderr\n" if $stderr;  # do not hide standard errors, if any
+	my ($code, $msg) = Monitor::Simple::Utils->process_exit ($command, $exit_code, $stdout);
+	$outputter->out ($service->{id}, $code, $msg);
+	unless (exists $args->{nonotif} and $args->{nonotif}) {
+	    $notifier->notify ( { service => $service->{id},
+				  code    => $code,
+				  msg     => $msg } );
+	}
+	$pm->finish;
     }
 
     # here the parent branch continue when all child process have been
@@ -156,18 +170,6 @@ sub check_services {
 }
 
 
-1; # End of Monitor::Simple
-
-__END__
-=pod
-
-=head1 NAME
-
-Monitor::Simple - Simple monitoring of applications and services
-
-=head1 VERSION
-
-version 0.2.8
 
 =head1 SYNOPSIS
 
@@ -383,6 +385,7 @@ For exploring configuration, the I<Monitor::Simple> distribution has
 directory F<Monitor/Simple/configs> with few examples of configuration
 files.
 
+
 =head2 Plugins
 
 The plugins are external scripts that are invoked to do the real
@@ -437,7 +440,7 @@ method C<Monitor::Simple::UserAgent-E<gt>head_or_exit()>.
 
 =head3 Plugin: B<check-post.pl>
 
-This is a slightly generalized L<check-url.pl|"Plugin:_check-url.pl">
+This is a slightly generalized L<check-url.pl|plugin__check_url_pl>
 plugin. It can do also the C<head-test>s (as the C<check-url.pl> does)
 but its main purpose is to send data to the service using the I<HTTP
 POST> method. It allows you to check whether your service returns
@@ -480,7 +483,7 @@ method C<Monitor::Simple::UserAgent-E<gt>post_or_exit()>.
 
 =head3 Plugin: B<check-get.pl>
 
-This is very similar to L<check-post.pl|"Plugin:_check-post.pl"> plugin,
+This is very similar to L<check-post.pl|plugin__check_post_pl> plugin,
 except it uses I<HTTP GET> method. And, therefore, it does not use
 C<data> tag in the configuration file (because all input data are
 already part of the C<url> tag). It does not use I<HTTP HEAD> method.
@@ -843,6 +846,7 @@ And then you do whatever your notifier needs to do. You can use the
 logging system by calling C<Log::Log4perl> so-called "easy" methods:
 DEBUG(), INFO(), WARN(), ERROR(), LOGDIE() and LOGWARN().
 
+
 =head1 MODULES and METHODS
 
 The best way to explore modules, methods and how to use them is to
@@ -864,14 +868,17 @@ following keys and values:
 
 =over
 
+=item config => $config
+
 =item config_file -> $file
 
-A mandatory argument. It specifies what configuration to use.
+At least one of these two keys must be given. It specifies which
+configuration to use.
 
 =item outputter => an instance of I<Monitor::Simple::Output>
 
 This outputter will be responsible for creating the summary report of
-all checks. If not given, a default outputter is used.
+all checks. If not givne, a default outputter is used.
 
 =item filter => hashref or arrayref or scalar
 
@@ -926,7 +933,7 @@ It reads configuration from a file and returns it as a hashref. The
 configuration is looked for in the given $filename or in a default
 configuration file name. The path to both given and default
 configuration file is resolved by rules defined in
-L<resolve_config_file()|"resolve_config_file_($filename)">. The default
+L<resolve_config_file()|resolve_config_file___filename_>. The default
 configuration file name is in
 C<$Monitor::Simple::DEFAULT_CONFIG_FILE>.
 
@@ -934,9 +941,11 @@ C<$Monitor::Simple::DEFAULT_CONFIG_FILE>.
 
 Return a hashref with configuration for a given service (identified by
 its $service_id). If such configuration cannot be found, a warning is
-issued and undef is returned. The service configuration is looked for
-in the given hashref $config containing the full configuration
-(usually obtained by L<get_config()|"get_config_([$filename])">).
+issued and an (almost) empty hashref is returned. The service
+configuration is looked for in the given hashref $config containing
+the full configuration (usually obtained by
+L<get_config()|get_config____filename__>).
+
 
 =head2 Monitor::Simple::UserAgent
 
@@ -947,20 +956,20 @@ methods.
 =head3 head_or_exit ($service_id, $config)
 
 It makes the I<HTTP HEAD> test described in
-L<check_url.pl|"Plugin:_check-url.pl"> plugin. If everything okay it
+L<check_url.pl|plugin__check_url_pl> plugin. If everything okay it
 just returns. Otherwise, it exits with the Nagios-compliant reporting
 (see more about it in
-L<report_and_exit()|"report_and_exit_($service_id,_$config,_$exit_code,_$return_msg)">).
+L<report_and_exit()|report_and_exit___service_id___config___exit_code___return_msg_>).
 
 This method uses C<head-test> portion of this service configuration.
 
 =head3 post_or_exit ($service_id, $config)
 
 It makes the I<HTTP POST> test described in
-L<check_post.pl|"Plugin:_check-post.pl"> plugin. If everything okay it
+L<check_post.pl|plugin__check_post_pl> plugin. If everything okay it
 just returns. Otherwise, it exits with the Nagios-compliant reporting
 (see more about it in
-L<report_and_exit()|"report_and_exit_($service_id,_$config,_$exit_code,_$return_msg)">).
+L<report_and_exit()|report_and_exit___service_id___config___exit_code___return_msg_>).
 
 This method uses C<post-test> portion of this service configuration.
 
@@ -1003,7 +1012,7 @@ C<onlyerr> arguments:
 
    no         no         all output to STDOUT
 
-   no         yes        only errors to STDOUT
+   no         yes        only errors to STDOUT 
    ---------------------------------------------
 
 =item format => tsv | human | html
@@ -1021,7 +1030,8 @@ F<Monitor/Simple/configs/monitor-default.css>.
 
 =back
 
-=head3 list_formats
+
+=head3 list_formats 
 
 A class method. It returns a hashref with a list of actually supported
 formats (keys) and their description (values). At the time of writing
@@ -1104,13 +1114,14 @@ the log messages as defined by in Log::Log4Perl; default value being
 
 When writing a plugin or a notifier, this method is called for you
 automatically from the
-L<parse_plugin_args()|"parse_plugin_args_($default_service_id,_@args)">
-or L<parse_notifier_args()|"parse_notifier_args_(@args)">.
+L<parse_plugin_args()|parse_plugin_args___default_service_id___args_>
+or L<parse_notifier_args()|parse_notifier_args___args_>.
 
 =head3 get_logging_options
 
 It returns currently used logging options - in the same format as the
-same options are define in L<log_init()|"log_init_($logging_options)">.
+same options are define in L<log_init()|log_init___logging_options_>.
+
 
 =head2 Monitor::Simple::Utils
 
@@ -1139,7 +1150,7 @@ It executes an external program with the given arguments and
 (optionally) checks its STDOUT for the given content. If everything
 okay it just returns. Otherwise, it exits with the Nagios-compliant
 reporting (see more about it in
-L<report_and_exit()|"report_and_exit_($service_id,_$config,_$exit_code,_$return_msg)">).
+L<report_and_exit()|report_and_exit___service_id___config___exit_code___return_msg_>).
 
 This method uses C<prg-test> portion of this service configuration.
 
@@ -1153,10 +1164,18 @@ addresses (may be empty for some notifiers). It uses logging options
 (if any found in $args) to set the logging system. Read about possible
 arguments in $args in L<"Notifiers">.
 
+
+=head1 AUTHOR
+
+Martin Senger, C<< <martin.senger at gmail.com> >>
+
 =head1 BUGS
 
-Please report any bugs or feature requests to
-L<http://github.com/msenger/Monitor-Simple/issues>.
+Please report any bugs or feature requests to C<bug-monitor-simple at
+rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Monitor-Simple>.  I
+will be notified, and then you'll automatically be notified of
+progress on your bug as I make changes.
 
 =head2 Known bugs and limitations
 
@@ -1173,25 +1192,54 @@ locking.
 
 Similarly, log files are not using any locking.
 
+=item Timeout for plugin C<check-prg.pl>
+
+There should be also an option specifying a timeout (same as it is for
+Web-based plugins).
+
 =back
 
-=head1 ACKNOWLEDGMENT
+=head1 SUPPORT
 
-Thanks to Gisbert W. Selke C<< <gws@cpan.org> >> the tests should be
-now working also under Windows. He also provided a new version of the
-C<check_mem.pl> - under the name I<check_mem2.pl> - a plugin, that
-should work both under Windows and Unix.
+You can find documentation for this module with the perldoc command.
 
-=head1 AUTHOR
+    perldoc Monitor::Simple
 
-Martin Senger <martin.senger@gmail.com>
 
-=head1 COPYRIGHT AND LICENSE
+You can also look for information at:
 
-This software is copyright (c) 2013 by Martin Senger, CBRC-KAUST (Computational Biology Research Center - King Abdullah University of Science and Technology) All Rights Reserved.
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Monitor-Simple>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Monitor-Simple>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Monitor-Simple>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Monitor-Simple/>
+
+=back
+
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2011, Martin Senger, KAUST (King Abdullah University of Science and Technology) All Rights Reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+1; # End of Monitor::Simple
