@@ -2,9 +2,6 @@
 # Monitor::Simple::Log
 # Author: Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
-#
-# ABSTRACT: See documentation in Monitor::Simple
-# PODNAME: Monitor::Simple::Log
 #-----------------------------------------------------------------
 
 package Monitor::Simple::Log;
@@ -13,8 +10,6 @@ use warnings;
 use strict;
 use Log::Log4perl qw(:easy);
 
-our $VERSION = '0.2.8'; # VERSION
-
 my $default_loglevel  = 'INFO';
 my $default_logfile   = 'smonitor.log';
 #my $default_logformat = '%d (%r) %p> %F{1}:%L - %m%n';
@@ -36,8 +31,8 @@ sub get_logging_options {
 # undefined). For example:
 #
 # Monitor::Simple::Log->log_init ({ level  => $opt_loglevel,
-#                                 file   => $opt_logfile,
-#                                 layout => $opt_logformat });
+#	 		          file   => $opt_logfile,
+#			          layout => $opt_logformat });
 # -----------------------------------------------------------------
 sub log_init {
     my ($self, $args) = @_;
@@ -48,10 +43,10 @@ sub log_init {
     # log level
     my $opt_loglevel = $args->{level};
     if ($opt_loglevel) {
-        my $level = Log::Log4perl::Level::to_priority (uc ($opt_loglevel));
-        $logger_conf->{level} = $level;
+	my $level = Log::Log4perl::Level::to_priority (uc ($opt_loglevel));
+	$logger_conf->{level} = $level;
     } else {
-        $logger_conf->{level} = Log::Log4perl::Level::to_priority ($default_loglevel);
+	$logger_conf->{level} = Log::Log4perl::Level::to_priority ($default_loglevel);
     }
 
     # log file
@@ -59,7 +54,7 @@ sub log_init {
     $opt_logfile ||= $default_logfile;
     $opt_logfile =~ s{^[><]+}{};   # I had problems when '>' was there; it created binary log file (TBD?)
     if ($opt_logfile ne 'STDOUT' and $opt_logfile ne 'STDERR' and $opt_logfile !~ m{^>}) {
-        $opt_logfile = ">>$opt_logfile";
+	$opt_logfile = ">>$opt_logfile";
     }
     $logger_conf->{file} = $opt_logfile;
 
@@ -86,28 +81,3 @@ sub logging_args {
 }
 
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-Monitor::Simple::Log - See documentation in Monitor::Simple
-
-=head1 VERSION
-
-version 0.2.8
-
-=head1 AUTHOR
-
-Martin Senger <martin.senger@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Martin Senger, CBRC-KAUST (Computational Biology Research Center - King Abdullah University of Science and Technology) All Rights Reserved.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
